button test

# Test of instantiating many buttons

Warning: these benchmarks will take a number of seconds to run. Other system activity will cause these benchmarks to skew.

The results should not be compared between browsers for they are run on different systems, however results for the same browser are relative to each other.

## Result

(divide by 100 to get time per widget)

## Typical results

IE6 | IE7 | Safari | Gecko (on PC) | Gecko (on intel mac)
--- | --- | --- | --- | ---
25812 (258ms/widget) | 10391 (103ms/widget) | 1934 (19ms/widget) | 1344 (13ms/widget) | 2937 (29ms/widget)